refreshInfiniteQuery<DataType, ErrorType, PageType> method
Finds the InfiniteQuery with the given key and refreshes
using InfiniteQuery.refresh
It'll return the refreshed data and will return null if fails
exactcan be used to match the key exactly or by prefixpagecan be used to only refresh a specific page or else it'll refresh the lastPage
Implementation
Future<DataType?> refreshInfiniteQuery<DataType, ErrorType, PageType>(
String key, {
PageType? page,
bool exact = true,
}) async {
final query =
getInfiniteQuery<DataType, ErrorType, PageType>(key, exact: exact);
if (query == null) return null;
return await query.refresh(page);
}