refreshQuery<DataType, ErrorType> method
Finds the Query with the given key and refreshes using Query.refresh
exact can be used to match the key exactly or by prefix
Implementation
Future<DataType?> refreshQuery<DataType, ErrorType>(
String key, {
bool exact = true,
}) async {
final query = getQuery<DataType, ErrorType>(key, exact: exact);
if (query == null) return null;
return await query.refresh();
}